# Usage of Configuration Files
You can see instructions of how to use the `default.yaml` and `enabled.yaml` configuration files at the top of the files themselves.

All other configuration files are filled with minimal (or empty) content to create as little bloatware as possible. You can find basic instructions for each configuration file in the files themselves as comments, and otherwise you can refer to this [example configuration repository](https://github.com/ArturoRoberti/gurk_config).
